@@ -6,7 +6,7 @@ import hashlib
 from .ciphertextmessage import CiphertextMessage
 from ..util.byteutil import ByteUtil
 from ..ecc.curve import Curve
-from . import whisperprotos
+from . import whisperprotos_pb2 as whisperprotos
 from ..legacymessageexception import LegacyMessageException
 from ..invalidmessageexception import InvalidMessageException
 from ..invalidkeyexception import InvalidKeyException
