@@ -1,6 +1,10 @@
+# -*- coding: utf-8 -*-
+
 from ..ecc.curve import Curve
 from ..kdf.derivedrootsecrets import DerivedRootSecrets
 from .chainkey import ChainKey
+
+
 class RootKey:
     def __init__(self, kdf, key):
         self.kdf = kdf
@@ -11,7 +15,10 @@ class RootKey:
 
     def createChain(self, ECPublicKey_theirRatchetKey, ECKeyPair_ourRatchetKey):
         sharedSecret = Curve.calculateAgreement(ECPublicKey_theirRatchetKey, ECKeyPair_ourRatchetKey.getPrivateKey())
-        derivedSecretBytes = self.kdf.deriveSecrets(sharedSecret, bytearray("WhisperRatchet".encode()), DerivedRootSecrets.SIZE, salt = self.key)
+        derivedSecretBytes = self.kdf.deriveSecrets(sharedSecret,
+                                                    bytearray("WhisperRatchet".encode()),
+                                                    DerivedRootSecrets.SIZE,
+                                                    salt=self.key)
         derivedSecrets = DerivedRootSecrets(derivedSecretBytes)
         newRootKey = RootKey(self.kdf, derivedSecrets.getRootKey())
         newChainKey = ChainKey(self.kdf, derivedSecrets.getChainKey(), 0)
